from dexa_protocol.v1_0.message_types import SPEC_URI

TAGS_DDA_LABEL = "Data Disclosure Agreements"
TAGS_DDA = {
    "name": TAGS_DDA_LABEL,
    "description": "Data Disclosure Agreement - Core Functions",
    "externalDocs": {
        "description": "Specification",
        "url": SPEC_URI,
    },
}


TAGS_MARKETPLACE_LABEL = "Data Marketplace"
TAGS_MARKETPLACE = {
    "name": TAGS_MARKETPLACE_LABEL,
    "description": "Data Marketplace - Core Functions",
    "externalDocs": {
        "description": "Specification",
        "url": SPEC_URI,
    },
}
